from __future__ import print_function


# https://gist.github.com/christian-oudard/220521/16f5ee5e3c54653846445dbedd67d30f2328d5a3
"""
Utilities for 256 color support in terminals.
Adapted from:
http://stackoverflow.com/questions/1403353/256-color-terminal-library-for-ruby
The color palette is indexed as follows:
0-15: System colors
    0  black         8  dark gray
    1  dark red      9  red
    2  dark green    10 green
    3  dark yellow   11 yellow
    4  dark blue     12 blue
    5  dark purple   13 purple
    6  dark cyan     14 cyan
    7  light gray    15 white
16-231: 6x6x6 Color Cube
    All combinations of red, green, and blue from 0 to 5.
232-255: Grayscale Ramp
    24 shades of gray, not including black and white.
"""


def rgb(red, green, blue):
    """
    Calculate the palette index of a color in the 6x6x6 color cube.
    The red, green and blue arguments may range from 0 to 5.
    """
    return 16 + (red * 36) + (green * 6) + blue


def gray(value):
    """
    Calculate the palette index of a color in the grayscale ramp.
    The value argument may range from 0 to 23.
    """
    return 232 + value


def set_color(fg=None, bg=None):
    """
    Print escape codes to set the terminal color.
    fg and bg are indices into the color palette for the foreground and
    background colors.
    """
    if fg:
        print("\x1b[38;5;%dm" % fg, end="")
    if bg:
        print("\x1b[48;5;%dm" % bg, end="")


def reset_color():
    """
    Reset terminal color to default.
    """
    print("\x1b[0m", end="")


def print_color(*args, **kwargs):
    """
    Print function, with extra arguments fg and bg to set colors.
    """
    fg = kwargs.pop("fg", None)
    bg = kwargs.pop("bg", None)
    set_color(fg, bg)
    print(*args, **kwargs)
    reset_color()


def color_test(args):
    # Print a test graphic showing all colors.
    if args != "ascii":
        spc = 67
        sp_ = " " * spc
        sp_ += "\tColor Test"
        print()
        print(sp_)
        print(" " * 67, end="")
    else:
        print("\n\tColor Test")
        print(" " * 2, end="")
    for c in range(8):
        print_color("   ", bg=c, end="")
    print()
    if args != "ascii":
        print(" " * 67, end="")
    else:
        print(" " * 2, end="")
    for c in range(8, 16):
        print_color("   ", bg=c, end="")
    print()
    print()



from tcolorpy import tcolor
import getpass
import os

host = os.uname()[1]
username = "- "+getpass.getuser()
spc=""
spc_=""
ch=""
t=""

def modify(choice,info):
    global ch
    global t
    global spc
    global spc_
    global username
    ch="ASCII:"+choice["charac"] +" "
    t="Theme:"+choice["theme"]
    k=len(info[9]) + len(host) + len(username) + len("ram : ")
    spc = "=" * len(ch + t + " ") 
    spc_="=" * k
    k1 = " " * (k - (len(host) + len(username)))
    username = k1 + username

def dragon(info,field_colors,choice):
    modify(choice,info[9])
    print("")
    print(tcolor(f"           /           /     {ch}{t}              ",color=field_colors[0],styles=["bold"]))
    print(tcolor(f"          /' .,,,,  ./       {spc}                ",color=field_colors[1],styles=["bold"]))
    print(tcolor(f"         /';'     ,/         ◼ {info[0]}          ",color=field_colors[0],styles=["bold"]))
    print(tcolor(f"        / /   ,,//,`'`       ◼ {info[1]}          ",color=field_colors[1],styles=["bold"]))
    print(tcolor(f"       ( ,, '_,  ,,,' ``     ◼ {info[2]}          ",color=field_colors[2],styles=["bold"]))
    print(tcolor(f"       |    /@  ,,, ;'' `    ◼ {info[3]}          ",color=field_colors[3],styles=["bold"]))
    print(tcolor(f"      /    .   ,''/' `,``    ◼ {info[4]}          ",color=field_colors[4],styles=["bold"]))
    print(tcolor(f"     /   .     ./, `,, ` ;   ◼ {info[5]}          ",color=field_colors[5],styles=["bold"]))
    print(tcolor(f"  ,./  .   ,-,',` ,,/''\,'   ◼ {info[6]}          ",color=field_colors[6],styles=["bold"]))
    print(tcolor(f" |   /; ./,,'`,,'' |   |     ◼ {info[7]}          ",color=field_colors[7],styles=["bold"]))
    print(tcolor(f" |     /   ','    /    |     ◼ {info[8]}          ",color=field_colors[2],styles=["bold"]))
    print(tcolor(f"  \___/'   '     |     |     ◼ {info[9]}          ",color=field_colors[3],styles=["bold"]))
    print(tcolor(f"    `,,'  |      /     `\    {spc_}               ",color=field_colors[0],styles=["bold"]))
    print(tcolor(f"         /      |        \   {username}@{host}    ",color=field_colors[1],styles=["bold"]))
    print("")


def monalisa(info,field_colors,choice):
    modify(choice,info[9])
    print("")
    print(tcolor(f"           ____                                   ",color=field_colors[0],styles=["bold"]))
    print(tcolor(f"         o8%8888,                                 ",color=field_colors[4],styles=["bold"]))
    print(tcolor(f"       o88%8888888.                               ",color=field_colors[6],styles=["bold"]))
    print(tcolor(f"      8'-    -:8888b                              ",color=field_colors[1],styles=["bold"]))
    print(tcolor(f"     8'         8888         {ch}{t}              ",color=field_colors[2],styles=["bold"]))
    print(tcolor(f"    d8.-=. ,==-.:888b        {spc}                ",color=field_colors[6],styles=["bold"]))
    print(tcolor(f"    >8 `~` :`~' d8888        m {info[0]}          ",color=field_colors[0],styles=["bold"]))
    print(tcolor(f"    88         ,88888        o {info[1]}          ",color=field_colors[1],styles=["bold"]))
    print(tcolor(f"    88b. `-~  ':88888        n {info[2]}          ",color=field_colors[2],styles=["bold"]))
    print(tcolor(f"    888b ~==~ .:88888        a {info[3]}          ",color=field_colors[3],styles=["bold"]))
    print(tcolor(f"    88888o--:':::8888        l {info[4]}          ",color=field_colors[4],styles=["bold"]))
    print(tcolor(f"    `88888| :::' 8888b       i {info[5]}          ",color=field_colors[5],styles=["bold"]))
    print(tcolor(f"    8888^^'       8888b      s {info[6]}          ",color=field_colors[6],styles=["bold"]))
    print(tcolor(f"   d888           ,%888b.    a {info[7]}          ",color=field_colors[7],styles=["bold"]))
    print(tcolor(f"  d88%            %%%8--'-.  > {info[8]}          ",color=field_colors[3],styles=["bold"]))
    print(tcolor(f" /88:.__ ,       _%-' ---  - < {info[9]}          ",color=field_colors[2],styles=["bold"]))
    print(tcolor(f"     '''::===..-'   =  --.  ` {spc_}              ",color=field_colors[0],styles=["bold"]))
    print(tcolor(f"                              {username}@{host}   ",color=field_colors[3],styles=["bold"]))
    print("")


def casper(info,field_colors,choice):
    modify(choice,info[9])
    print("")
    print(tcolor(f"     .-''''-.            {ch}{t}                  ",color=field_colors[5],styles=["bold"]))
    print(tcolor(f"    / -   -  \           {spc}                    ",color=field_colors[7],styles=["bold"]))
    print(tcolor(f"   |  .-. .- |           @ {info[0]}              ",color=field_colors[0],styles=["bold"]))
    print(tcolor(f"   |  \o| |o (           # {info[1]}              ",color=field_colors[1],styles=["bold"]))
    print(tcolor(f"   \     ^    \          % {info[2]}              ",color=field_colors[2],styles=["bold"]))
    print(tcolor(f"   |'.  )--'  /|         $ {info[3]}              ",color=field_colors[3],styles=["bold"]))
    print(tcolor(f"  / / '-. .-'`\ \        ! {info[4]}              ",color=field_colors[4],styles=["bold"]))
    print(tcolor(f" / /'---` `---'\ \       ^ {info[5]}              ",color=field_colors[5],styles=["bold"]))
    print(tcolor(f" '.__.       .__.'       & {info[6]}              ",color=field_colors[6],styles=["bold"]))
    print(tcolor(f"     `|     |`           ~ {info[7]}              ",color=field_colors[7],styles=["bold"]))
    print(tcolor(f"      |     \            + {info[8]}              ",color=field_colors[3],styles=["bold"]))
    print(tcolor(f"      \      '--.        - {info[9]}              ",color=field_colors[1],styles=["bold"]))
    print(tcolor(f"       '.        `\      {spc_}                   ",color=field_colors[2],styles=["bold"]))
    print(tcolor(f"         `'---.   |      {username}@{host}        ",color=field_colors[6],styles=["bold"]))
    print(tcolor(f"            ,__) /                                ",color=field_colors[0],styles=["bold"]))
    print(tcolor(f"             `..'                                 ",color=field_colors[1],styles=["bold"]))
    print("")



def egyptian(info,field_colors,choice):
    modify(choice,info[9])
    print("")
    print(tcolor(f"             ?                                                               ",color=field_colors[6],styles=["bold"]))
    print(tcolor(f"         ____'_                   |   |                {ch}{t}               ",color=field_colors[2],styles=["bold"]))
    print(tcolor(f"        /'  _)))                  |\_/|______,         {spc}                 ",color=field_colors[1],styles=["bold"]))
    print(tcolor(f"       /===| _\                  /::| Q  ____)         𓅃 {info[0]}           ",color=field_colors[0],styles=["bold"]))
    print(tcolor(f"      ('___|   >   ,_           /:::|   /    ,_        𓃀 {info[1]}           ",color=field_colors[1],styles=["bold"]))
    print(tcolor(f"         o  _=    / _///       /::::|_ /    / _///     𓂀 {info[2]}           ",color=field_colors[2],styles=["bold"]))
    print(tcolor(f"   _______| |____/ |         _|:::::| |:___/ |         𓁖 {info[3]}           ",color=field_colors[3],styles=["bold"]))
    print(tcolor(f"  |  __)  \_/ /____|        | '----'\_/  /___|         𓉢 {info[4]}           ",color=field_colors[4],styles=["bold"]))
    print(tcolor(f" _| / \    ) )             _| /  \   :  /              𓆘 {info[5]}           ",color=field_colors[5],styles=["bold"]))
    print(tcolor(f"\__/   \    /             \__/    \    /               𓄀 {info[6]}           ",color=field_colors[6],styles=["bold"]))
    print(tcolor(f"       /   (                      /===(                𓀀 {info[7]}           ",color=field_colors[7],styles=["bold"]))
    print(tcolor(f"      / \   \                    /     \               𓃔 {info[8]}           ",color=field_colors[3],styles=["bold"]))
    print(tcolor(f"     /   \   \                  /       \              𓃑 {info[9]}           ",color=field_colors[2],styles=["bold"]))
    print(tcolor(f"     |    \   \                 |        \             {spc_}                ",color=field_colors[1],styles=["bold"]))
    print(tcolor(f"     |     \   \                |         \            {username}@{host}     ",color=field_colors[4],styles=["bold"]))
    print(tcolor(f"     |      \   \               |,_________\                                 ",color=field_colors[2],styles=["bold"]))
    print(tcolor(f"     |       \   \               /  )  / )                                   ",color=field_colors[1],styles=["bold"]))
    print(tcolor(f"     |,_______\___\             /  /  (  |                                   ",color=field_colors[0],styles=["bold"]))
    print(tcolor(f"       | /   \ |                | /    \ |                                   ",color=field_colors[7],styles=["bold"]))
    print(tcolor(f"       |/     \|                |/      \|                                   ",color=field_colors[6],styles=["bold"]))
    print(tcolor(f"       S__     S__              S__      S__                                 ",color=field_colors[5],styles=["bold"]))
    print(tcolor(f"      /___\   /___\            /___\    /___\                                ",color=field_colors[4],styles=["bold"]))
    print("")


def fairy(info,field_colors,choice):
    modify(choice,info[9])
    print("")
    print(tcolor(f"       .--.   _,                                       ",color=field_colors[3],styles=["bold"]))
    print(tcolor(f"   .--;    \ /(_                  {ch}{t}              ",color=field_colors[4],styles=["bold"]))
    print(tcolor(f"  /    '.   |   '-._    . ' .     {spc}                ",color=field_colors[6],styles=["bold"]))
    print(tcolor(f" |       \  \    ,-.)  -= * =-    * {info[0]}          ",color=field_colors[2],styles=["bold"]))
    print(tcolor(f"  \ /\_   '. \((` .(    '/. '     * {info[1]}          ",color=field_colors[0],styles=["bold"]))
    print(tcolor(f"   )\ /     \ )\  _/   _/         * {info[2]}          ",color=field_colors[1],styles=["bold"]))
    print(tcolor(f"  /  \ \   .-'   '--. /_\         * {info[3]}          ",color=field_colors[3],styles=["bold"]))
    print(tcolor(f" |    \ \_.' ,       \/||         * {info[4]}          ",color=field_colors[4],styles=["bold"]))
    print(tcolor(f" \     \_.-';,_) _)'\ \||         * {info[5]}          ",color=field_colors[5],styles=["bold"]))
    print(tcolor(f"  '.       /`\   (   '._/         * {info[6]}          ",color=field_colors[6],styles=["bold"]))
    print(tcolor(f"    `\   .;  |  . '.              * {info[7]}          ",color=field_colors[7],styles=["bold"]))
    print(tcolor(f"      ).'  )/|      \             * {info[8]}          ",color=field_colors[4],styles=["bold"]))
    print(tcolor(f"      `    ` |  \|   |            * {info[9]}          ",color=field_colors[3],styles=["bold"]))
    print(tcolor(f"              \  |   |            {spc_}               ",color=field_colors[2],styles=["bold"]))
    print(tcolor(f"               '.|   |            {username}@{host}    ",color=field_colors[0],styles=["bold"]))
    print(tcolor(f"                  \  '\__                              ",color=field_colors[6],styles=["bold"]))
    print(tcolor(f"                   `-._  '. _                          ",color=field_colors[3],styles=["bold"]))
    print(tcolor(f"                      \`;-.` `._                       ",color=field_colors[2],styles=["bold"]))
    print(tcolor(f"                       \ \ `'-._\                      ",color=field_colors[4],styles=["bold"]))
    print(tcolor(f"                        \ |                            ",color=field_colors[5],styles=["bold"]))
    print(tcolor(f"                         \ )                           ",color=field_colors[7],styles=["bold"]))
    print(tcolor(f"                          \_\                          ",color=field_colors[6],styles=["bold"]))
    print("")
